# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_json_schema_item import (
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
)

AgentsSearchResponseAgentsItemToolsItemJsonSchema = typing.Union[
    typing.Optional[typing.Any],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem]],
]
